RelationLeafNN<K, V> class
A many-to-many RelationLeaf. No cardinality constraints.
- Inheritance
-
- Object
- RelationLeaf<
K, V> - RelationLeafNN
Constructors
-
RelationLeafNN([Iterable<
(K, V)> ? data])
Properties
- garden → Garden
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
no setterinherited
- isNotEmpty → bool
-
no setterinherited
- keyCount → int
-
The number of distinct keys in the relation.
no setterinherited
-
keys
→ Iterable<
K> -
All keys that have at least one association.
no setterinherited
- length → int
-
The total number of pairs in the relation.
no setterinherited
-
pairs
→ Iterable<
(K, V)> -
All (key, value) pairs in the relation.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- valueCount → int
-
The number of distinct values in the relation.
no setterinherited
-
values
→ Iterable<
V> -
All values that have at least one association.
no setterinherited
Methods
-
add(
K key, V value) → void -
Adds a pair. Throws ArgumentError if it would violate the cardinality.
inherited
-
clear(
) → void -
Removes all pairs.
inherited
-
containsKey(
K key) → bool -
inherited
-
containsPair(
K key, V value) → bool -
inherited
-
containsValue(
V value) → bool -
inherited
-
getKeys(
V value) → Iterable< K> -
Returns the keys associated with
value, or an empty iterable. -
getValues(
K key) → Iterable< V> -
Returns the values associated with
key, or an empty iterable. -
move(
K key, V value) → void -
Adds a pair, silently removing any conflicting associations first.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
record(
void undo()) → void -
Records an inverse mutation to support Garden.revert.
inherited
-
remove(
K key, V value) → bool -
Removes a specific pair. Returns true if it existed.
inherited
-
removeKey(
K key) → Set< V> -
Removes all pairs for
key. Returns the removed values.inherited -
removeValue(
V value) → Set< K> -
Removes all pairs for
value. Returns the removed keys.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited